redvox.api1000.wrapped_redvox_packet API documentation

# Module `redvox.api1000.wrapped_redvox_packet`

## Sub-modules

`redvox.api1000.wrapped_redvox_packet.event_streams`

  This module provides a wrapper for API M event streams which are used to record events derived from sensor data on stations.

`redvox.api1000.wrapped_redvox_packet.sensors`
`redvox.api1000.wrapped_redvox_packet.station_information`

  This module provides access to underlying station information from RedVox API M data.

`redvox.api1000.wrapped_redvox_packet.timing_information`

  Contains methods for accessing and setting timing and time synchronization fields.

`redvox.api1000.wrapped_redvox_packet.wrapped_packet`

  This module provides a high level API for creating, reading, and editing RedVox compliant API 1000 files.